@@ -2,15 +2,19 @@
 #'
 #' @export
 #' @param id the taxon identifier code
-#' @param ... Further args passed on to \code{\link[httr]{GET}}
+#' @param ... Further args passed on to \code{\link[crul]{verb-GET}}
 #' @return A data.frame
+#' @family nbn
+#' @references <https://api.nbnatlas.org/>
 #' @examples \dontrun{
-#' nbn_synonyms(id = 'NHMSYS0000502940')
 #' nbn_synonyms(id = 'NHMSYS0001501147')
 #' nbn_synonyms(id = 'NHMSYS0000456036')
+#'
+#' # none
+#' nbn_synonyms(id = 'NHMSYS0000502940')
 #' }
-
 nbn_synonyms <- function(id, ...) {
-  url <- sprintf("https://data.nbn.org.uk/api/taxa/%s/synonyms", id)
-  nbn_GET_2(url, ...)
+  url <- file.path(nbn_base(), "species", id)
+  df <- nbn_GET_2(url, ...)
+  df$synonyms
 }
