@@ -1,10 +1,9 @@
 context("gbif_parse")
 
-
 test_that("gbif_parse returns the correct values and dimensions classes", {
-  skip_on_cran()
-
-  tt <- gbif_parse(scientificname = 'x Agropogon littoralis L.')
+  vcr::use_cassette("gbif_parse", {
+    tt <- gbif_parse(scientificname = 'x Agropogon littoralis L.')
+  })
 
   expect_match(as.character(tt[1,1]), 'x Agropogon littoralis')
 	expect_match(as.character(tt[1,2]), 'SCIENTIFIC')
