@@ -1,13 +1,12 @@
-# tests for tp_synonyms fxn in taxize
 context("tp_synonyms")
 
-
 test_that("tp_synonyms returns the correct value", {
-  skip_on_cran()
+  skip_on_cran() # uses secrets
+  vcr::use_cassette("tp_synonyms", {
+    dat <- suppressMessages(tp_synonyms(id = 25509881))
+  })
 
-  dat <- suppressMessages(tp_synonyms(id = 25509881))
-
-  expect_that(names(dat)[[1]], matches("accepted"))
+  expect_match(names(dat)[[1]], "accepted")
 
 	expect_that(dat, is_a("list"))
 	expect_that(dat[[1]], is_a("data.frame"))
